<?php

	require_once 'Image/Tools.php';

	class Image_Tools_Border extends Image_Tools {

		/**
		* Configuration options
		*
		* @var array
		*/
		
		var $options = array ( 'x'	 		=> false,
							   'y' 			=> false,
							   'width' 		=> false,
							   'height'		=> false,
							   'fgColor' 	=> false,
							   'bgColor' 	=> false,
							   'lineWidth' 	=> 1,
							   'roundWidth' => 0);

		/**
		* Constructor
		* The constructor is normaly called in the factory method of the
		* inherited class @see Image_Tools, where you can provide the options 
		* array, as follows:
		*
		* <pre>
		*	array(
		*		'x' => top left corner x coordinate
		*		'y' => top left corner y coordinate
		*		'width' => width of the border
		*		'height' => height of the border
		*		'fgColor' => color of the border
		*		'bgColor' => color of the background
		*		'lineWidth' => thickness of the border, default is 1
		*		'roundWidth' => width of the edge rounding, default is no round
		*	)
		* </pre>
		*
		* @access public
		* @param array $options Options as described above.
		*/
							    
		function Image_Tools_Border ( $options = array() ) {
			foreach ( $options as $option => $value) {
				if (isset($this->options[$option])) {
					$this->options[$option] = $value;
				}
			}
		}

		/**
		* Draw the border to the image
		* This draws the configured border to the provided image. Beware, that 
		* every pixel inside the border clipping will be overwritten with the
		* given background color. This will be changed in the next release.
		*
		* @access public
		* @return void
		*/
		
		function draw ( ) {
			$o = $this->options;
			
            $fgCol = imagecolorallocate($this->img, $o['fgColor']['r'], $o['fgColor']['g'], $o['fgColor']['b']);
            $bgCol = imagecolorallocate($this->img, $o['bgColor']['r'], $o['bgColor']['g'], $o['bgColor']['b']);

            // FG
            $startXfg = $o['x'] - $o['lineWidth'];
            $startYfg = $o['y'] - $o['lineWidth'];
            $endXfg =  $o['x'] + $o['width'] + $o['lineWidth'];
            $endYfg = $o['y'] + $o['height'] + $o['lineWidth'];

            $res = imagefilledrectangle($this->img, $startXfg, $startYfg, $endXfg, $endYfg, $fgCol);

            // BG:
            $startXbg = $o['x'];
            $startYbg = $o['y'];
            $endXbg = $o['x'] + $o['width'];
            $endYbg = $o['y'] + $o['height'];

            $res = imagefilledrectangle($this->img, $startXbg, $startYbg, $endXbg, $endYbg, $bgCol);

            if ($o['roundWidth'] > 0) {

                // Top left corner erase
                $res = imagefilledrectangle($this->img, $startXfg, $startYfg, $startXfg + $o['roundWidth'] + $o['lineWidth'], $startYfg + $o['roundWidth'] + $o['lineWidth'], $bgCol);
                // Bottom left corner erase
                $res = imagefilledrectangle($this->img, $startXfg, $endYfg - $o['roundWidth'] - $o['lineWidth'], $startXfg + $o['roundWidth'] + $o['lineWidth'], $endYfg, $bgCol);
                // Bottom right corner erase
                $res = imagefilledrectangle($this->img, $endXfg - $o['roundWidth'] - $o['lineWidth'], $endYfg -  $o['roundWidth'] - $o['lineWidth'], $endXfg, $endYfg, $bgCol);
                // Top right corner erase
                $res = imagefilledrectangle($this->img, $endXfg - $o['roundWidth'] - $o['lineWidth'], $startYfg, $endXfg, $startYfg + $o['roundWidth'] + $o['lineWidth'], $bgCol);

                // Top left corner arc
                $res = imagefilledarc($this->img, $startXfg + $o['roundWidth'] + $o['lineWidth'], $startYfg + $o['roundWidth'] + $o['lineWidth'], ($o['roundWidth'] + $o['lineWidth']) * 2, ($o['roundWidth'] + $o['lineWidth']) * 2, 180, 270, $fgCol, IMG_ARC_PIE);
                // Top right corner arc
                $res = imagefilledarc($this->img, $endXfg - $o['roundWidth'] - $o['lineWidth'], $startYfg + $o['roundWidth'] + $o['lineWidth'], ($o['roundWidth'] + $o['lineWidth']) * 2, ($o['roundWidth'] + $o['lineWidth']) * 2, 270, 0, $fgCol, IMG_ARC_PIE);
                // Bottom right corner arc
                $res = imagefilledarc($this->img, $endXfg - $o['roundWidth'] - $o['lineWidth'], $endYfg - $o['roundWidth'] - $o['lineWidth'], ($o['roundWidth'] + $o['lineWidth']) * 2, ($o['roundWidth'] + $o['lineWidth']) * 2, 0, 90, $fgCol, IMG_ARC_PIE);
                // Bottom left corner arc
                $res = imagefilledarc($this->img, $startXfg + $o['roundWidth'] + $o['lineWidth'], $endYfg - $o['roundWidth'] - $o['lineWidth'], ($o['roundWidth'] + $o['lineWidth']) * 2, ($o['roundWidth'] + $o['lineWidth']) * 2, 90, 180, $fgCol, IMG_ARC_PIE);


                // Top left corner arc
                $res = imagefilledarc($this->img, $startXfg + $o['roundWidth'] + $o['lineWidth'], $startYfg + $o['roundWidth'] + $o['lineWidth'], $o['roundWidth'] * 2, $o['roundWidth'] * 2, 180, 270, $bgCol, IMG_ARC_PIE);
                // Top right corner arc
                $res = imagefilledarc($this->img, $endXfg - $o['roundWidth'] - $o['lineWidth'], $startYfg + $o['roundWidth'] + $o['lineWidth'], $o['roundWidth'] * 2, $o['roundWidth'] * 2, 270, 0, $bgCol, IMG_ARC_PIE);
                // Bottom right corner arc
                $res = imagefilledarc($this->img, $endXfg - $o['roundWidth'] - $o['lineWidth'], $endYfg - $o['roundWidth'] - $o['lineWidth'], $o['roundWidth'] * 2, $o['roundWidth'] * 2, 0, 90, $bgCol, IMG_ARC_PIE);
                // Bottom left corner arc
                $res = imagefilledarc($this->img, $startXfg + $o['roundWidth'] + $o['lineWidth'], $endYfg - $o['roundWidth'] - $o['lineWidth'], $o['roundWidth'] * 2, $o['roundWidth'] * 2, 90, 180, $bgCol, IMG_ARC_PIE);			
            }
		}
	}
?>